<?php

#NLS (National Language System) array.

#Portuguese 

#Native language name
$nls['language']['pt_PT'] = 'Português de Portugal';
$nls['englishlang']['pt_PT'] = 'Portuguese';

#Possible aliases for language
$nls['alias']['pt'] = 'pt_PT';
$nls['alias']['portuguese'] = 'pt_PT' ;
$nls['alias']['port'] = 'pt_PT' ;
$nls['alias']['pt-PT'] = 'pt_PT' ;
$nls['alias']['pt_PT'] = 'pt_PT' ;

#Possible locale for language
$nls['locale']['pt_PT'] = 'pt_PT,pt_PT.utf8,pt_PT.UTF-8,pt_PT.utf-8,pt_PT@euro,portuguese,Portuguese_Portugal.1252';

#Encoding of the language
$nls['encoding']['pt_PT'] = 'UTF-8';

#Location of the file(s)
$nls['file']['pt_PT'] = array(dirname(__FILE__).'/pt_PT/admin.inc.php');

#Language setting for HTML area
# Only change this when translations exist in HTMLarea and plugin dirs
# (please send language files to HTMLarea development)

$nls['htmlarea']['pt_PT'] = 'pt_pt';
?>
